@@ -12,23 +12,30 @@ import yaml
 import six
 from six.moves import input, map
 
+
 def start_interpreter(**variables):
     # add the current working directory to the sys paths
     sys.path.append(os.getcwd())
-    console = type('shopify ' + shopify.version.VERSION, (code.InteractiveConsole, object), {})
+    console = type("shopify " + shopify.version.VERSION, (code.InteractiveConsole, object), {})
     import readline
+
     console(variables).interact()
 
+
 class ConfigFileError(Exception):
     pass
 
+
 def usage(usage_string):
     """Decorator to add a usage string to a function"""
+
     def decorate(func):
         func.usage = usage_string
         return func
+
     return decorate
 
+
 class TasksMeta(type):
     _prog = os.path.basename(sys.argv[0])
 
@@ -37,23 +44,26 @@ class TasksMeta(type):
 
         tasks = list(new_attrs.keys())
         tasks.append("help")
+
         def filter_func(item):
             return not item.startswith("_") and hasattr(getattr(cls, item), "__call__")
+
         tasks = filter(filter_func, tasks)
         cls._tasks = sorted(tasks)
 
         return cls
 
     def run_task(cls, task=None, *args):
-        if task in [None, '-h', '--help']:
+        if task in [None, "-h", "--help"]:
             cls.help()
             return
 
         # Allow unambigious abbreviations of tasks
         if task not in cls._tasks:
             matches = filter(lambda item: item.startswith(task), cls._tasks)
-            if len(matches) == 1:
-                task = matches[0]
+            list_of_matches = list(matches)
+            if len(list_of_matches) == 1:
+                task = list_of_matches[0]
             else:
                 sys.stderr.write('Could not find task "%s".\n' % (task))
 
@@ -78,7 +88,7 @@ class TasksMeta(type):
                 if desc:
                     line = "%s%s  # %s" % (line, " " * (max_len - len(line)), desc)
                 if len(line) > cols:
-                    line = line[:cols - 3] + "..."
+                    line = line[: cols - 3] + "..."
                 print(line)
         else:
             task_func = getattr(cls, task)
@@ -110,22 +120,22 @@ class Tasks(object):
         if os.path.exists(filename):
             raise ConfigFileError("There is already a config file at " + filename)
         else:
-            config = dict(protocol='https')
+            config = dict(protocol="https")
             domain = input("Domain? (leave blank for %s.myshopify.com) " % (connection))
             if not domain.strip():
                 domain = "%s.myshopify.com" % (connection)
-            config['domain'] = domain
+            config["domain"] = domain
             print("")
             print("open https://%s/admin/apps/private in your browser to generate API credentials" % (domain))
-            config['api_key'] = input("API key? ")
-            config['password'] = input("Password? ")
-            config['api_version'] = input("API version? (leave blank for %s) " % (cls._default_api_version))
-            if not config['api_version'].strip():
-                config['api_version'] = cls._default_api_version
+            config["api_key"] = input("API key? ")
+            config["password"] = input("Password? ")
+            config["api_version"] = input("API version? (leave blank for %s) " % (cls._default_api_version))
+            if not config["api_version"].strip():
+                config["api_version"] = cls._default_api_version
 
             if not os.path.isdir(cls._shop_config_dir):
                 os.makedirs(cls._shop_config_dir)
-            with open(filename, 'w') as f:
+            with open(filename, "w") as f:
                 f.write(yaml.dump(config, default_flow_style=False, explicit_start="---"))
         if len(list(cls._available_connections())) == 1:
             cls.default(connection)
@@ -205,14 +215,16 @@ class Tasks(object):
 
     @classmethod
     @usage("version")
-    def version(cls, connection=None):
+    def version(cls):
         """output the shopify library version"""
         print(shopify.version.VERSION)
 
     @classmethod
     def _available_connections(cls):
-        return map(lambda item: os.path.splitext(os.path.basename(item))[0],
-              glob.glob(os.path.join(cls._shop_config_dir, "*.yml")))
+        return map(
+            lambda item: os.path.splitext(os.path.basename(item))[0],
+            glob.glob(os.path.join(cls._shop_config_dir, "*.yml")),
+        )
 
     @classmethod
     def _default_connection_target(cls):
@@ -221,7 +233,6 @@ class Tasks(object):
         target = os.readlink(cls._default_symlink)
         return os.path.join(cls._shop_config_dir, target)
 
-
     @classmethod
     def _default_connection(cls):
         target = cls._default_connection_target()
@@ -252,6 +263,7 @@ class Tasks(object):
     def _no_config_file_error(cls, filename):
         raise ConfigFileError("There is no config file at " + filename)
 
+
 try:
     Tasks.run_task(*sys.argv[1:])
 except ConfigFileError as e:
